@@ -16,7 +16,7 @@ Usage::
     session_client: SagemakerFeatureStoreRuntimeClient = session.client("sagemaker-featurestore-runtime")
     ```
 """
-from mypy_boto3_sagemaker_featurestore_runtime.client import SagemakerFeatureStoreRuntimeClient
+from .client import SagemakerFeatureStoreRuntimeClient
 
 Client = SagemakerFeatureStoreRuntimeClient
 
